@@ -33,6 +33,7 @@ __all__ = (
     "StateType",
     "TypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -332,10 +333,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -343,3 +346,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_data_set_revisions", "list_data_sets", "list_jobs", "list_revision_assets"
+]
